@@ -2,6 +2,11 @@ from summ.splitter.splitter import Splitter
 
 
 class OtterSplitter(Splitter):
+    """Adds Splitter support for transcripts exported from otter.ai.
+
+    To filter out your own remarks, pass a list of speakers to exclude.
+    """
+
     def __init__(self, speakers_to_exclude: list[str] = []) -> None:
         super().__init__()
         self.exclude = speakers_to_exclude
